[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

xserver-xorg-input-citron: Changes to 'upstream-unstable'



 .cvsignore      |   19 -----------------
 .gitignore      |   26 +++++++++++++++++++++++
 ChangeLog       |   61 --------------------------------------------------------
 Makefile.am     |   10 +++++++++
 README          |   19 +++++++++++++++++
 configure.ac    |   19 ++++++++++-------
 man/citron.man  |    2 -
 src/Makefile.am |    2 +
 src/citron.c    |   23 ++++++++++++++-------
 9 files changed, 85 insertions(+), 96 deletions(-)

New commits:
commit 7c202dd28ae9c6fffd7ae958a21463ae69c51a8a
Author: Alan Coopersmith <alan.coopersmith@sun.com>
Date:   Tue Apr 28 17:51:32 2009 -0700

    Version 2.2.2
    
    Signed-off-by: Alan Coopersmith <alan.coopersmith@sun.com>

diff --git a/configure.ac b/configure.ac
index 7aaf638..748ebbd 100644
--- a/configure.ac
+++ b/configure.ac
@@ -22,7 +22,7 @@
 
 AC_PREREQ(2.57)
 AC_INIT([xf86-input-citron],
-        2.2.1,
+        2.2.2,
         [https://bugs.freedesktop.org/enter_bug.cgi?product=xorg],
         xf86-input-citron)
 

commit d411ee98f95c62bb63cab88a5fa97be6e4fb057e
Author: Alan Coopersmith <alan.coopersmith@sun.com>
Date:   Tue Apr 28 17:50:51 2009 -0700

    Delete duplicate EXTRA_DIST line from Makefile
    
    Signed-off-by: Alan Coopersmith <alan.coopersmith@sun.com>

diff --git a/Makefile.am b/Makefile.am
index b607f62..1817e61 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -20,7 +20,7 @@
 
 AUTOMAKE_OPTIONS = foreign
 SUBDIRS = src man
-EXTRA_DIST = ChangeLog
+
 EXTRA_DIST = ChangeLog
 MAINTAINERCLEANFILES = ChangeLog
 

commit 32dbc726871bf7e3a7535d788f169f8e11c981fd
Author: Paulo Cesar Pereira de Andrade <pcpa@mandriva.com.br>
Date:   Mon Feb 2 18:32:11 2009 -0200

    Janitor: correct make distcheck.

diff --git a/.gitignore b/.gitignore
index d6882bf..03555bf 100644
--- a/.gitignore
+++ b/.gitignore
@@ -22,3 +22,5 @@ stamp-h1
 .deps
 .libs
 man/citron.?
+xf86-input-citron-*.tar.*
+tags
diff --git a/Makefile.am b/Makefile.am
index 42f8b54..b607f62 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -20,11 +20,13 @@
 
 AUTOMAKE_OPTIONS = foreign
 SUBDIRS = src man
-
-CLEANFILES = ChangeLog
 EXTRA_DIST = ChangeLog
+EXTRA_DIST = ChangeLog
+MAINTAINERCLEANFILES = ChangeLog
 
 .PHONY: ChangeLog
 
 ChangeLog:
-	(GIT_DIR=$(top_srcdir)/.git git-log > .changelog.tmp && mv .changelog.tmp ChangeLog; rm -f .changelog.tmp) || (touch ChangeLog; echo 'git directory not found: installing possibly empty changelog.' >&2)
+	$(CHANGELOG_CMD)
+
+dist-hook: ChangeLog
diff --git a/configure.ac b/configure.ac
index b96b34a..7aaf638 100644
--- a/configure.ac
+++ b/configure.ac
@@ -32,15 +32,16 @@ AM_INIT_AUTOMAKE([dist-bzip2])
 
 AM_MAINTAINER_MODE
 
-DRIVER_NAME=citron
-AC_SUBST([DRIVER_NAME])
-
+# Require xorg-macros: XORG_CWARNFLAGS, XORG_CHANGELOG
+m4_ifndef([XORG_MACROS_VERSION], [AC_FATAL([must install xorg-macros 1.2 or later before running autoconf/autogen])])
+XORG_MACROS_VERSION(1.2)
 AM_CONFIG_HEADER([config.h])
 
 # Checks for programs.
 AC_DISABLE_STATIC
 AC_PROG_LIBTOOL
 AC_PROG_CC
+XORG_CWARNFLAGS
 
 AH_TOP([#include "xorg-server.h"])
 
@@ -77,16 +78,18 @@ XORG_DRIVER_CHECK_EXT(XINPUT, [inputproto >= 1.4.1])
 # Checks for pkg-config packages
 PKG_CHECK_MODULES(XORG, [xorg-server >= 1.0.99.901] xproto $REQUIRED_MODULES)
 sdkdir=$(pkg-config --variable=sdkdir xorg-server)
-
-CFLAGS="$CFLAGS $XORG_CFLAGS "' -I$(top_srcdir)/src'
-AC_SUBST([CFLAGS])
+XORG_CFLAGS="$CWARNFLAGS $XORG_CFLAGS"
 
 # Checks for libraries.
 
 # Checks for header files.
 AC_HEADER_STDC
 
+DRIVER_NAME=citron
+AC_SUBST([DRIVER_NAME])
+
 XORG_MANPAGE_SECTIONS
 XORG_RELEASE_VERSION
+XORG_CHANGELOG
 
 AC_OUTPUT([Makefile src/Makefile man/Makefile])
diff --git a/src/Makefile.am b/src/Makefile.am
index 5ff68eb..920ef23 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -24,6 +24,8 @@
 # -avoid-version prevents gratuitous .0.0.0 version numbers on the end
 # _ladir passes a dummy rpath to libtool so the thing will actually link
 # TODO: -nostdlib/-Bstatic/-lgcc platform magic, not installing the .a, etc.
+AM_CFLAGS = $(XORG_CFLAGS)
+
 @DRIVER_NAME@_drv_la_LTLIBRARIES = @DRIVER_NAME@_drv.la
 @DRIVER_NAME@_drv_la_LDFLAGS = -module -avoid-version
 @DRIVER_NAME@_drv_ladir = @inputdir@

commit 6f479966a1f5f9ab376a0b6144548e5f3da76b12
Author: Alan Coopersmith <alan.coopersmith@sun.com>
Date:   Fri Jan 30 20:17:02 2009 -0800

    Add README with pointers to mailing list, bugzilla & git repos

diff --git a/README b/README
new file mode 100644
index 0000000..aeb61cf
--- /dev/null
+++ b/README
@@ -0,0 +1,19 @@
+
+Please submit bugs & patches to the Xorg bugzilla:
+
+        https://bugs.freedesktop.org/enter_bug.cgi?product=xorg
+
+All questions regarding this software should be directed at the
+Xorg mailing list:
+
+        http://lists.freedesktop.org/mailman/listinfo/xorg
+
+The master development code repository can be found at:
+
+        git://anongit.freedesktop.org/git/xorg/driver/xf86-input-citron
+
+        http://cgit.freedesktop.org/xorg/driver/xf86-input-citron
+
+For more information on the git code manager, see:
+
+        http://wiki.x.org/wiki/GitPage

commit 52b092a77ef19c77bf40cd6896c0d1e54d5f5f62
Author: Alan Coopersmith <alan.coopersmith@sun.com>
Date:   Fri Jan 9 16:11:02 2009 -0800

    Remove xorgconfig & xorgcfg from See Also list in man page

diff --git a/man/citron.man b/man/citron.man
index 0aec323..eb93367 100644
--- a/man/citron.man
+++ b/man/citron.man
@@ -903,6 +903,6 @@ is the duration in [ms].
 "60" 
 
 .SH "SEE ALSO"
-__xservername__(__appmansuffix__), __xconfigfile__(__filemansuffix__), xorgconfig(1), Xserver(1), X(__miscmansuffix__).
+__xservername__(__appmansuffix__), __xconfigfile__(__filemansuffix__), Xserver(1), X(__miscmansuffix__).
 .SH "AUTHORS"
 2000\-2005 \- written  by  Citron GmbH (support@citron.de)

commit 0297c49fd3743e15900a05169ba36e6a0fb438c0
Author: Peter Hutterer <peter.hutterer@redhat.com>
Date:   Thu Aug 14 14:55:59 2008 +0930

    Fix build, XF86_VERSION_CURRENT doesn't exist anymore.

diff --git a/src/citron.c b/src/citron.c
index 38e5067..c7f6c3c 100644
--- a/src/citron.c
+++ b/src/citron.c
@@ -1368,7 +1368,10 @@ DeviceInit (DeviceIntPtr dev)
 	 * screen to fit one meter.
 	 * Device may reports touch pressure on the 3rd axis.
 	 */
-	if (InitValuatorClassDeviceStruct (dev, 2, xf86GetMotionEvents,
+	if (InitValuatorClassDeviceStruct (dev, 2,
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) < 3
+                    xf86GetMotionEvents,
+#endif
 									local->history_size, Absolute) == FALSE)
 	{
 		ErrorF ("%sUnable to allocate Citron touchscreen ValuatorClassDeviceStruct\n", CI_ERROR);

commit a59ffb3cdc9d68a0ad21f04831e4255ad0e985d8
Author: Paulo Cesar Pereira de Andrade <pcpa@mandriva.com>
Date:   Mon Feb 4 01:10:27 2008 -0200

    Don't call xf86SoundKbdBell and xf86XInputSetSendCoreEvents
    
    Only call those functions if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 0.
    
    Signed-off-by: Peter Hutterer <peter@cs.unisa.edu.au>

diff --git a/src/citron.c b/src/citron.c
index 42152b5..38e5067 100644
--- a/src/citron.c
+++ b/src/citron.c
@@ -2058,12 +2058,14 @@ SwitchMode (ClientPtr client, DeviceIntPtr dev, int mode)
 		DBG(6, ErrorF("%s\treporting mode = %s\n", CI_INFO, mode==TS_Raw?"raw":"scaled"));
 		return (Success);
 	}
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 0
 	else if ((mode == SendCoreEvents) || (mode == DontSendCoreEvents))
 	{
 		xf86XInputSetSendCoreEvents (local, (mode == SendCoreEvents));
 		DBG(6, ErrorF("%s\tmode = %sSend Core Events\n", CI_INFO, mode==DontSendCoreEvents?"Don\'t ":""));
 		return (Success);
 	}
+#endif
 #ifdef CIT_MODE_EXT
 	else if (mode == ClickMode_Enter)
 	{
@@ -2466,6 +2468,7 @@ cit_Beep(cit_PrivatePtr priv, int press)
 	if(priv->beep == 0)
 		return;
 
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 0
 	/* ring release bell */
 	if(press == 0)
 
@@ -2492,6 +2495,7 @@ cit_Beep(cit_PrivatePtr priv, int press)
 	else
 	/* ring press bell */
 		xf86SoundKbdBell(priv->press_vol,priv->press_pitch, priv->press_dur);
+#endif
 
 	DBG(7, ErrorF("%scit_Beep called - %s\n", CI_INFO, (press == 0) ? "release" : "press"));
 #endif
@@ -2508,6 +2512,7 @@ cit_BeepKey(cit_PrivatePtr priv, int press)
 	if(priv->beepkey == 0)
 		return;
 
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 0
 	/* ring release bell */
 	if(press <= 0)
 
@@ -2532,6 +2537,7 @@ cit_BeepKey(cit_PrivatePtr priv, int press)
 	else
 	/* ring press bell */
 		xf86SoundKbdBell(priv->presskey_vol,priv->presskey_pitch, priv->presskey_dur);
+#endif
 
 	DBG(7, ErrorF("%scit_BeepKey called - %s\n", CI_INFO, (press == 0) ? "release" : "press"));
 #endif

commit 9a4d7854273a34c1a32f46fb52f2f8c3a227cd12
Author: Tilman Sauerbeck <tilman@code-monkey.de>
Date:   Sun Sep 9 17:09:45 2007 +0200

    Generate ChangeLog from git.

diff --git a/.gitignore b/.gitignore
index 1ccf7e3..d6882bf 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,3 +1,4 @@
+ChangeLog
 Makefile
 Makefile.in
 *.la
diff --git a/ChangeLog b/ChangeLog
deleted file mode 100644
index 62fa058..0000000
--- a/ChangeLog
+++ /dev/null
@@ -1,61 +0,0 @@
-2006-04-06  Adam Jackson  <ajax@freedesktop.org>
-
-	* configure.ac:
-	* src/citron.c:
-	Unlibcwrap.  Bump server version requirement.  Bump to 2.2.0.
-
-2006-03-01  Peter Kunzmann  <kunzmann@citron.de>
-
-	* man/citron.man:
-	Change most -'s to \-.
-	Update list of supported devices.
-
-	* src/citron.c:
-	* src/citron.h:
-	Call the PostButton event when breaking beams.
-	Added channels for ambient overload, keys and pwmex channels.
-	Beep on keyclicks.
-	Bug #6065: Add NULL to default_options[] to prevent crash.
-
-	* configure.ac:
-	Bump to version 2.15.
-
-2005-12-20  Kevin E. Martin  <kem-at-freedesktop-dot-org>
-
-	* configure.ac:
-	Update package version for X11R7 release.
-
-2005-12-14  Kevin E. Martin  <kem-at-freedesktop-dot-org>
-
-	* configure.ac:
-	Update package version number for final X11R7 release candidate.
-
-2005-12-06  Kevin E. Martin  <kem-at-freedesktop-dot-org>
-
-	* man/Makefile.am:
-	Change *man_SOURCES ==> *man_PRE to fix autotools warnings.
-
-2005-12-03  Kevin E. Martin  <kem-at-freedesktop-dot-org>
-
-	* configure.ac:
-	Update package version number for X11R7 RC3 release.
-
-2005-12-01  Kevin E. Martin  <kem-at-freedesktop-dot-org>
-
-	* configure.ac:
-	Remove extraneous AC_MSG_RESULT.
-
-2005-11-29  Adam Jackson  <ajax@freedesktop.org>
-
-	* configure.ac:
-	Only build dlloader modules by default.
-
-2005-11-09  Kevin E. Martin  <kem-at-freedesktop-dot-org>
-
-	* configure.ac:
-	Update package version number for X11R7 RC2 release.
-
-2005-11-01  Kevin E. Martin  <kem-at-freedesktop-dot-org>
-
-	* configure.ac:
-	Update pkgcheck dependencies to work with separate build roots.
diff --git a/Makefile.am b/Makefile.am
index 7052905..42f8b54 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -20,3 +20,11 @@
 
 AUTOMAKE_OPTIONS = foreign
 SUBDIRS = src man
+
+CLEANFILES = ChangeLog
+EXTRA_DIST = ChangeLog
+
+.PHONY: ChangeLog
+
+ChangeLog:
+	(GIT_DIR=$(top_srcdir)/.git git-log > .changelog.tmp && mv .changelog.tmp ChangeLog; rm -f .changelog.tmp) || (touch ChangeLog; echo 'git directory not found: installing possibly empty changelog.' >&2)

commit f2cd377905ba74d6c13ab9e4f4491146e90a7e0d
Author: Tilman Sauerbeck <tilman@code-monkey.de>
Date:   Sun Sep 9 17:03:33 2007 +0200

    Added some more patterns to .gitignore.

diff --git a/.gitignore b/.gitignore
index 2df4a8d..1ccf7e3 100644
--- a/.gitignore
+++ b/.gitignore
@@ -18,3 +18,6 @@ ltmain.sh
 missing
 stamp-h1
 *~
+.deps
+.libs
+man/citron.?

commit 83adcd21fade2746b9a1b8e3ca3cc097db440919
Author: Tilman Sauerbeck <tilman@code-monkey.de>
Date:   Sun Sep 9 17:02:23 2007 +0200

    Bumped version to 2.2.1.

diff --git a/configure.ac b/configure.ac
index 9d8bdf0..b96b34a 100644
--- a/configure.ac
+++ b/configure.ac
@@ -22,7 +22,7 @@
 
 AC_PREREQ(2.57)
 AC_INIT([xf86-input-citron],
-        2.2.0,
+        2.2.1,
         [https://bugs.freedesktop.org/enter_bug.cgi?product=xorg],
         xf86-input-citron)
 

commit a7295991a74b725a27efb1ed07ba4e396374b288
Author: Alan Coopersmith <alan.coopersmith@sun.com>
Date:   Fri Sep 7 10:14:14 2007 -0700

    Move from TSCalibrationCtl to AbsCalibCtl - requires inputproto >= 1.4.1
    
    Based on xf86-input-dmc commit 43a05fb4cb02f15fc91d0909a3cab37a9de6b622 by
    Daniel Stone.

diff --git a/configure.ac b/configure.ac
index 3ce3686..9d8bdf0 100644
--- a/configure.ac
+++ b/configure.ac
@@ -72,7 +72,7 @@ AC_SUBST(inputdir)
 
 # Checks for extensions
 XORG_DRIVER_CHECK_EXT(RANDR, randrproto)
-XORG_DRIVER_CHECK_EXT(XINPUT, inputproto)
+XORG_DRIVER_CHECK_EXT(XINPUT, [inputproto >= 1.4.1])
 
 # Checks for pkg-config packages
 PKG_CHECK_MODULES(XORG, [xorg-server >= 1.0.99.901] xproto $REQUIRED_MODULES)
diff --git a/src/citron.c b/src/citron.c
index 7b1021d..42152b5 100644
--- a/src/citron.c
+++ b/src/citron.c
@@ -2020,7 +2020,7 @@ static void cit_ProcessPacket(cit_PrivatePtr priv)
 static int
 ControlProc (LocalDevicePtr local, xDeviceCtl * control)
 {
-	xDeviceTSCalibrationCtl *c = (xDeviceTSCalibrationCtl *) control;
+	xDeviceAbsCalibCtl *c = (xDeviceAbsCalibCtl *) control;
 	cit_PrivatePtr priv = (cit_PrivatePtr) (local->private);
 
  	DBG(5, ErrorF("%sControlProc called\n", CI_INFO));

commit 75aca9fa1429ca9e2aa696c32cb77ca12d8c7856
Author: Brice Goglin <bgoglin@debian.org>
Date:   Tue Aug 7 09:50:40 2007 +0200

    Define CITOUCH_VERSION* using PACKAGE_VERSION*

diff --git a/src/citron.c b/src/citron.c
index 4e90a83..7b1021d 100644
--- a/src/citron.c
+++ b/src/citron.c
@@ -138,12 +138,12 @@
 #define INITT 0		/* Initialisation of touch in first loop */
 
 
-#define CITOUCH_VERSION	0x220
 char version[]="Touch Driver V2.2.0  (c) 1999-2006 Citron GmbH";
 
-#define CITOUCH_VERSION_MAJOR ((CITOUCH_VERSION >> 8) & 0xf)
-#define CITOUCH_VERSION_MINOR ((CITOUCH_VERSION >> 4) & 0xf)
-#define CITOUCH_VERSION_PATCH ((CITOUCH_VERSION >> 0) & 0xf)
+#define CITOUCH_VERSION PACKAGE_VERSION
+#define CITOUCH_VERSION_MAJOR PACKAGE_VERSION_MAJOR
+#define CITOUCH_VERSION_MINOR PACKAGE_VERSION_MINOR
+#define CITOUCH_VERSION_PATCH PACKAGE_VERSION_PATCHLEVEL
 
 
 /*****************************************************************************

commit 53a748872a1468845b99e7d9b90f2fcebf45c2b7
Author: Alan Coopersmith <alan.coopersmith@sun.com>
Date:   Thu Mar 1 10:33:07 2007 -0800

    renamed: .cvsignore -> .gitignore

diff --git a/.cvsignore b/.cvsignore
deleted file mode 100644
index fb1befd..0000000
--- a/.cvsignore
+++ /dev/null
@@ -1,19 +0,0 @@
-Makefile
-Makefile.in
-*.la
-*.lo
-aclocal.m4
-autom4te.cache
-config.guess
-config.h
-config.h.in
-config.log
-config.status
-config.sub
-configure
-depcomp
-install-sh
-libtool
-ltmain.sh
-missing
-stamp-h1
diff --git a/.gitignore b/.gitignore
new file mode 100644
index 0000000..2df4a8d
--- /dev/null
+++ b/.gitignore
@@ -0,0 +1,20 @@
+Makefile
+Makefile.in
+*.la
+*.lo
+aclocal.m4
+autom4te.cache
+config.guess
+config.h
+config.h.in
+config.log
+config.status
+config.sub
+configure
+depcomp
+install-sh
+libtool
+ltmain.sh
+missing
+stamp-h1
+*~

commit af0c6207afdcacc75c37e51f9f6fc4da1e3f5f57
Author: Alan Coopersmith <alan.coopersmith@sun.com>
Date:   Thu Mar 1 10:32:45 2007 -0800

    Replace references to XFree86/XF86Config in man page

diff --git a/man/citron.man b/man/citron.man
index c6aa3d3..0aec323 100644
--- a/man/citron.man
+++ b/man/citron.man
@@ -903,6 +903,6 @@ is the duration in [ms].
 "60" 
 
 .SH "SEE ALSO"
-XFree86(1), XF86Config(__filemansuffix__), xf86config(1), Xserver(1), X(__miscmansuffix__).
+__xservername__(__appmansuffix__), __xconfigfile__(__filemansuffix__), xorgconfig(1), Xserver(1), X(__miscmansuffix__).
 .SH "AUTHORS"
 2000\-2005 \- written  by  Citron GmbH (support@citron.de)


Reply to:
diff --git a/src/citron.c b/src/citron.c
index c7f6c3c..eb83cf8 100644
--- a/src/citron.c
+++ b/src/citron.c
@@ -305,7 +305,7 @@ static XF86ModuleVersionInfo VersionRec =
 	MODULEVENDORSTRING,			/* vendor specific string */
 	MODINFOSTRING1,				
 	MODINFOSTRING2,
-	XF86_VERSION_CURRENT,		/* Current XFree version */
+	XORG_VERSION_CURRENT,		/* Current Xorg version */
 	CITOUCH_VERSION_MAJOR,		/* Module-specific major version */
 	CITOUCH_VERSION_MINOR,		/* Module-specific minor version */
 	CITOUCH_VERSION_PATCH,		/* Module-specific patch level */

commit 591674bee43061f1169ebeede653fb6d98147724
Author: Peter Hutterer <peter@cs.unisa.edu.au>
Date:   Mon May 26 22:03:52 2008 +0930

    Check for XINPUT ABI 3.
